@@ -245,7 +245,7 @@ class Client(Callbacks, SocketHandler):
         self.start()
         self.run_socket()
 
-    def login(self, email: str, password: str,proxy:bool=False):
+    def login(self, email: str, password: str,proxy:dict=None):
         """
         Login into an account.
 
@@ -258,13 +258,7 @@ class Client(Callbacks, SocketHandler):
 
             - **Fail** : :meth:`Exceptions <amino.lib.util.exceptions>`
         """
-        
-        if proxy is True:
-            data=json.dumps({"email":email,"password":password,"device":self.device_id})
-            response=requests.post("http://154.12.227.82:2193/login",data=data)
-
-        if proxy is False:
-            data = json.dumps({
+        data = json.dumps({
             "email": email,
             "v": 2,
             "secret": f"0 {password}",
@@ -272,26 +266,25 @@ class Client(Callbacks, SocketHandler):
             "clientType": 100,
             "action": "normal",
             "timestamp": int(timestamp() * 1000)
-            })
-            response = requests.post(f"{self.api}/g/s/auth/login", headers=self.parse_headers(data=data,deviceId=self.devicee()), data=data, proxies=self.proxies, verify=self.certificatePath)
-        
+        })
+        if proxy:
+            proxy=proxy
+        else:
+            proxy =self.proxies
+        response = requests.post(f"{self.api}/g/s/auth/login", headers=self.parse_headers(data=data), data=data, proxies=proxy, verify=self.certificatePath)
         self.run_socket()
-        res=response.json()
-        if res["api:statuscode"]!=0:
-            return exceptions.CheckException(json.loads(response.text))
+        if response.status_code != 200: return exceptions.CheckException(json.loads(response.text))
 
         else:
             self.authenticated = True
             self.json = json.loads(response.text)
             self.sid = self.json["sid"]
-            try: self.secret= self.json["secret"]
-            except: pass
             self.userId = self.json["account"]["uid"]
             self.account: objects.UserProfile = objects.UserProfile(self.json["account"]).UserProfile
             self.profile: objects.UserProfile = objects.UserProfile(self.json["userProfile"]).UserProfile
             headers.sid = self.sid
             self.start()
-            return json.loads(response.text)
+            return response.status_code
 
     def register(self, nickname: str, email: str, password: str, verificationCode: str, deviceId: str = device.device_id):
         """
