@@ -9,8 +9,11 @@ import requests
 import hmac
 import platform,socket,re,uuid 
 def device_gen():
-  d=requests.get("http://172.105.51.123/dev-gen").text
-  return d
+    hw=(names.get_full_name()+str(random.randint(0,10000000))+platform.version()+platform.machine()+names.get_first_name()+socket.gethostbyname(socket.gethostname())+':'.join(re.findall('..', '%012x' % uuid.getnode()))+platform.processor())
+    identifier=sha1(hw.encode('utf-8')).digest()
+    key='02b258c63559d8804321c5d5065af320358d366f'
+    mac = hmac.new(bytes.fromhex(key), b"\x42" + identifier, sha1)
+    return (f"42{identifier.hex()}{mac.hexdigest()}").upper()
 
 def generate_device_info():
     try:
